/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.login.client.AppliPanel;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.FrameElement;
import com.google.gwt.event.dom.client.LoadEvent;
import com.google.gwt.event.dom.client.LoadHandler;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.CssResource;
import com.google.gwt.resources.client.CssResource.ImportedWithPrefix;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.resources.client.ImageResource.ImageOptions;
import com.google.gwt.resources.client.ImageResource.RepeatStyle;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Frame;
import org.ow2.orchestra.login.client.InfoBar.PInfoBar;
import org.ow2.orchestra.login.client.LoginPanel.PLoginPanel;

/**
 * Class that contains the presenter of the application panel
 */
public class PAppliPanel{

  private VAppliPanelIF view;
  private Resources DEFAULT_RESOURCE;
  private Frame frame;

  public interface Resources extends ClientBundle{

	  @Source("../resources/org/ow2/orchestra/login/client/AppliPanel/orchestra_banner.png")
	  ImageResource orchestra_banner();

	  @Source("../resources/org/ow2/orchestra/login/client/AppliPanel/orchestra_fond.png")
	  @ImageOptions(repeatStyle = RepeatStyle.Both, flipRtl = true)
	  ImageResource orchestra_fond();

	  @Source(Style.DEFAULT_CSS)
	   Style style();
  }


  @ImportedWithPrefix("gwt-style")
  public interface Style extends CssResource {

	  String DEFAULT_CSS = "../resources/org/ow2/orchestra/login/client/AppliPanel/Appli.css";

	  String stylePanelParent();

	  String stylePanelBanner();
  }

  /**
   * provided a instance of Resources
   * @return
   */
  private Resources getResource(){
	  if(DEFAULT_RESOURCE == null){
		   DEFAULT_RESOURCE = GWT.create(Resources.class);
	  }
	  return DEFAULT_RESOURCE;
  }
  /**
   * Constructor of appli panel with tab layout panel
   * @param view : Complete class view of our application
   *
   */
  public PAppliPanel(VAppliPanelIF view) {
    StyleForView(view);
    this.bindingView(view);
    frame = new Frame(GWT.getHostPageBaseURL()+"index2.html");
    frame.setWidth("100%");
    frame.setHeight("100%");
    frame.setStyleName("frameStyle");
    frame.ensureDebugId("contentFrame");

    new PInfoBar(this);
    this.view.getContentPanel().add(frame);
    frame.addDomHandler(new LoadHandler() {
      public void onLoad(LoadEvent event) {
        Window.setTitle(frame.getElement().<FrameElement>cast().getContentDocument().getTitle());
      }
    }, LoadEvent.getType());
  }

  /**
   * Constructor of appli panel with login panel
   * @param view : the view of the appli panel
   * @param pLoginPanel : the presenter of the login panel
   *
   */
  public PAppliPanel(VAppliPanelIF view, PLoginPanel pLoginPanel) {
	    StyleForView(view);
	    this.bindingView(view);
	    this.view.getContentPanel().add(pLoginPanel.getView());
       Window.setTitle("Orchestra-Login");

  }

  /**
   * update the the style (css) of View AppliPanel
   * @param view
   */
  public void StyleForView (VAppliPanelIF view){
	    getResource().style().ensureInjected();
	    view.getAppliLayoutPanelParent().setStyleName(getResource().style().stylePanelParent());
		view.getAppliLayoutPanelOrcB().setStyleName(getResource().style().stylePanelBanner());
  }
  /**
   * Method to binf the view with its presenter
   *
   */
  protected void bindingView(final Object viewToBind) {
    this.view = (VAppliPanelIF) viewToBind;
  }

  public VAppliPanelIF getView(){
	  return view;
  }

}
