/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.login.client.InfoBar;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.Style.Unit;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.i18n.client.DateTimeFormat;
import com.google.gwt.i18n.shared.GwtLocale;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.CssResource;
import com.google.gwt.resources.client.CssResource.ImportedWithPrefix;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.rpc.AsyncCallback;
import java.util.Date;
import org.ow2.orchestra.login.client.AppliPanel.PAppliPanel;
import org.ow2.orchestra.login.client.LoginService;
import org.ow2.orchestra.login.client.LoginServiceAsync;


//import org.ow2.orchestra.login.client.ResourcesJava.ImageResources;



/**
 * Presenter of the info bar class.
 */
public class PInfoBar{
	/**
	   * Instantiate the stub of the login server
	   */
	  private final LoginServiceAsync loginService = GWT.create(LoginService.class);

  /**
   * Information about the user session.
   */
  private String userName = "";
  private String creationDate = "";
  private VInfoBarIF view = null;

  private Resources DEFAULT_RESOURCE;

  public interface Resources extends ClientBundle{

	  @Source("../resources/org/ow2/orchestra/login/client/InfoBar/fullingDownScreen.png")
	  ImageResource fullingDownScreen();

	  @Source("../resources/org/ow2/orchestra/login/client/InfoBar/fullingUpScreen.png")
	  ImageResource fullingUpScreen();

	  @Source("../resources/org/ow2/orchestra/login/client/InfoBar/logout_icon.gif")
	  ImageResource logout();

	  @Source(Style.DEFAULT_CSS)
	   Style style();
  }


  @ImportedWithPrefix("gwt-style")
  public interface Style extends CssResource {

	  String DEFAULT_CSS = "../resources/org/ow2/orchestra/login/client/InfoBar/InfoBar.css";

	  String infoFlowPanelStyle();

	  String infoLabelStyle();

	  String gwt_Image();

	  String orchestraLabelStyle();

	  //String disconnectLabelStyle();
  }

  /**
   * provided a instance of Resources
   * @return
   */
  private Resources getResource(){
	  if(DEFAULT_RESOURCE == null){
		   DEFAULT_RESOURCE = GWT.create(Resources.class);
	  }
	  return DEFAULT_RESOURCE;
  }

  /**
   * Constructor of the class
   * @param view : the view of the class
   */
  public PInfoBar(PAppliPanel appP) {
	//getResource().style().ensureInjected();
    VInfoBar vInfoBar = new VInfoBar();
    vInfoBar.setWidth("100%");
    vInfoBar.setHeight("3%");
    this.StyleForView(vInfoBar);
    this.bindingView(vInfoBar);

    appP.getView().getInfoPanel().add(vInfoBar);

    this.initInfoBar();
    
    this.setDebugID();

    this.addListeners(appP);
  }

  protected void bindingView(Object view) {
    this.view = (VInfoBarIF) view;
  }

  public void StyleForView (VInfoBar view){
	    getResource().style().ensureInjected();
	    view.getInfoLabel().setStyleName(getResource().style().infoLabelStyle());
	    view.getOrchestraLabel().setStyleName(getResource().style().orchestraLabelStyle());
	    view.getFpanel().setStyleName(getResource().style().infoFlowPanelStyle());
	    view.getFullScreen().setStyleName(getResource().style().gwt_Image());
  }
  
  
  /**
   * Define an id for each widget.
   * This Id is used by selenium for the integration tests phase.
   */
  protected void setDebugID() {
    this.view.getLogoutLabel().ensureDebugId("logoutButtonId");
    this.view.getInfoLabel().ensureDebugId("infoLabelId");
  }

  /**
   * Listeners on the widgets in the bar
   */
  protected void addListeners(final PAppliPanel appP) {

    //fullscreenlistener

    this.view.getFullScreen().addClickHandler(new ClickHandler() {

        public void onClick(ClickEvent arg0) {
        	if(appP.getView().isFullscreen()==false){
        		appP.getView().getAppliLayoutPanelParent().setWidgetTopHeight(appP.getView().getAppliLayoutPanelOrcB(), 0, Unit.PCT, 0, Unit.PCT);
            	appP.getView().getAppliLayoutPanelParent().setWidgetTopHeight(appP.getView().getInfoPanel(), 0, Unit.PCT, 20, Unit.PX);
            	appP.getView().getAppliLayoutPanelParent().setWidgetTopBottom(appP.getView().getContentPanel(), 20, Unit.PX, 0, Unit.PCT);
            	appP.getView().setFullscreen(true);
                view.getFullScreen().setResource(DEFAULT_RESOURCE.fullingDownScreen());
            	view.getFullScreen().setTitle("Exit Full Screen");
                view.getOrchestraLabel().setText("Orchestra");
        	}
        	else{
        		appP.getView().getAppliLayoutPanelParent().setWidgetTopHeight(appP.getView().getAppliLayoutPanelOrcB(), 0, Unit.PCT, 115, Unit.PX);
            	appP.getView().getAppliLayoutPanelParent().setWidgetTopHeight(appP.getView().getInfoPanel(), 116, Unit.PX, 20, Unit.PX);
            	appP.getView().getAppliLayoutPanelParent().setWidgetTopBottom(appP.getView().getContentPanel(), 137, Unit.PX, 0, Unit.PCT);
            	appP.getView().setFullscreen(false);
                view.getFullScreen().setResource(DEFAULT_RESOURCE.fullingUpScreen());
            	view.getFullScreen().setTitle("Full Screen");
                view.getOrchestraLabel().setText(" ");
        	}

        }
      });
    // logout listener
    this.view.getLogoutLabel().addClickHandler(new ClickHandler() {

      public void onClick(ClickEvent arg0) {

        loginService.sessionLogout(new AsyncCallback<Void>() {

          public void onSuccess(Void arg0) {
              Window.Location.reload();
          }
          public void onFailure(Throwable arg0) {
            GWT.log("logout fail !!!!");
          }
        });
      }
    });
  }

  public VInfoBarIF getView() {
    return this.view;
  }

  private void initInfoBar(){
	  loginService.getSessionUserName(new AsyncCallback<String>() {

	      public void onFailure(Throwable arg0) {
	      }

	      public void onSuccess(String arg0) {

	        userName = arg0;

	        loginService.getSessionCreationDate(new AsyncCallback<Long>() {

	          public void onFailure(Throwable arg0) {
	          }
	          public void onSuccess(Long arg0) {
	            Date date = new Date(arg0);
	            DateTimeFormat  processDateFormat = DateTimeFormat.getFormat("dd/MM/yyyy 'at' HH:mm:ss");

	            creationDate = processDateFormat.format(date);

	            PInfoBar.this.view.getInfoLabel().setText(" connected as " + userName);
                PInfoBar.this.view.getInfoLabel().setTitle(" connected since " + creationDate);
	          }
	        });
	      }
	    });

  }

}
