/*******************************************************************************
 * Copyright (C) 2010  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 *******************************************************************************/
package org.ow2.orchestra.login.client.LoginPanel;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.CssResource;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Widget;

/**
 * This class is the presenter of the panel used for the login page
 */
public class PLoginPanel{

  private VLoginPanelIF view;

  private Resources DEFAULT_RESOURCE;

  public interface Resources extends ClientBundle{

	  @Source("../resources/org/ow2/orchestra/login/client/LoginPanel/login.gif")
	  ImageResource login();

	  @Source("../resources/org/ow2/orchestra/login/client/LoginPanel/error_button.png")
	  ImageResource error_button();

	  @Source(Style.DEFAULT_CSS)
	   Style style();
  }


  public interface Style extends CssResource {

	  String DEFAULT_CSS = "../resources/org/ow2/orchestra/login/client/LoginPanel/LoginPanel.css";

	  String stylelogin();

	  String styleflowPanel();

	  String stylehonPanel();

	  String stylelabel();

	  String stylelegend();

	  String stylelogFailedLabel();

	  String stylepushButton();

	  String styleimg_error();
  }

  /**
   * provided a instance of Resources
   * @return
   */
  private Resources getResource(){
	  if(DEFAULT_RESOURCE == null){
		   DEFAULT_RESOURCE = GWT.create(Resources.class);
	  }
	  return DEFAULT_RESOURCE;
  }

  public PLoginPanel() {
	//
	getResource().style().ensureInjected();
	//
    VLoginPanelIF view = new VLoginPanel();
    this.bindingView(view);

    //
    this.setDebugID();

    //
    this.manageError();

  }

  /**
   * This method is used to hide or show the log failed message depending on the Href
   */
  private void manageError() { // Window.Location.getParameter("error").equals("error_login"))
    if (Window.Location.getHref().contains("j_security_check")) {
    	this.view.getLogFailedLabel().setVisible(true);
        this.view.getlogFailedBtn().setVisible(true);

    } else {
      	this.view.getLogFailedLabel().setVisible(false);
        this.view.getlogFailedBtn().setVisible(false);
    }
  }


  protected void bindingView(final Object view) {
    this.view = (VLoginPanelIF) view;
  }

  /**
   * Define an id for each widget.
   * This Id is used by selenium for the integration tests phase.
   */
  protected void setDebugID() {
    this.view.getFormPanel().ensureDebugId("loginFormPanelId");
    this.view.getUserNameField().ensureDebugId("userNameFieldId");
    this.view.getPasswordField().ensureDebugId("passwordFieldId");
    this.view.getLogFailedLabel().ensureDebugId("logFailedLabelId");
    this.view.getSubmitButton().ensureDebugId("submitButtonId");
  }


  /**
   *
   * @return
   */
  public Widget getView() {
    return (Widget) this.view;
  }
  /**
   * @return
   */
  public VLoginPanelIF getVLogin() {
	    return this.view;
  }


}
